function mtxGen = ReedMullerMatrix(r, m)
    %---------------------------------------------------------------------------
    % Usage:
    %    mtxGen = LinearCode.ReedMullerMatrix(m, r)
    % Description:
    %    Create a generator matrix for the r-th order Reed-Muller code of
    %    length 2^m.
    % Arguments:
    %    r
    %       The "order" of the Reed-Muller code generated by the resultant
    %       matrix.
    %    m
    %       The code generated by the resultant matrix will have length 2^m.
    % Note:
    %    The construction used here is taken from "Fundamentals of
    %    Error-Correcting Codes" by W. C. Huffman and V. Pless.
    %---------------------------------------------------------------------------
    
    assert(m > 0 && r >=0 && r <= m, ...
           ['The arguments `r` and `m` must integers with `m >= 1` and `0 <= ' ...
            'r <= m`.']);

    if (r == 0)
        mtxGen = ones(1, 2^m);
    elseif (r == m)
        mtxGen = eye(2^m);
    else
        A = LinearCode.ReedMullerMatrix(r, m-1);
        B = LinearCode.ReedMullerMatrix(r-1, m-1);
        mtxGen = [A, A; zeros(size(B, 1), size(A, 2)), B];
    end
end