% script to compute and plot clique topology for small matrices,
% to be used during practicum time in Mexico TDA lectures
% calls: CliqueTop package and generate_sq_dist_mtx.m

% FIRST, create or load an nxn matrix .....................................
n = 25; d = 10;
A = generate_sq_dist_mtx(n,d);
% A = rand(n);
% A = [0 1 2 3 4 5; 0 0 6 7 8 9; 0 0 0 10 11 12; 0 0 0 0 13 14;...
%     0 0 0 0 0 15; 0 0 0 0 0 0];

% symmetrize and put zeros on diagonal to get M
M = 0.5*(A + A') - diag(diag(A)); 

% SECOND, compute clique topology of M - including betti 0 ................
rho = 1; % max edge density in (0,1]
tic
[bettis, edgeDensities] = compute_clique_topology(M,'MaxEdgeDensity',rho,...
    'ComputeBetti0', true);
toc

% third, plot the Betti curves for b_0,...,b_3 ............................
colors = [.5 .5 .5; .6 .5 .1; .8 0 0; .3 .3 1];
figure
% plot matrix
subplot(3,3,1); imagesc(M); title('M'); 
% plot b_0 with a gray dashed line
subplot(3,1,2:3);
plot(edgeDensities,bettis(:,1),'--','color',colors(1,:),'LineWidth',1);
hold on;
% now plot b_1,b_2,b_3
for i=2:size(bettis,2)
    plot(edgeDensities,bettis(:,i),'color',colors(i,:),'LineWidth',2);
end;
xlabel('edge density')
ylabel('no. of cycles')
legend('\beta_0', '\beta_1', '\beta_2', '\beta_3')
title('Betti curves')
hold off;